@@ -15,10 +15,18 @@ KamereonPersonResponseSchema = marshmallow_dataclass.class_schema(
 )()
 
 
+KamereonVehicleContractsResponseSchema = marshmallow_dataclass.class_schema(
+    models.KamereonVehicleContractsResponse, base_schema=BaseSchema
+)()
+
 KamereonVehiclesResponseSchema = marshmallow_dataclass.class_schema(
     models.KamereonVehiclesResponse, base_schema=BaseSchema
 )()
 
+KamereonVehicleDetailsResponseSchema = marshmallow_dataclass.class_schema(
+    models.KamereonVehicleDetailsResponse, base_schema=BaseSchema
+)()
+
 
 KamereonVehicleDataResponseSchema = marshmallow_dataclass.class_schema(
     models.KamereonVehicleDataResponse, base_schema=BaseSchema
