@@ -11,6 +11,8 @@ import aiohttp
 
 from .credential_store import CredentialStore
 from .exceptions import RenaultException
+from .kamereon import get_required_contracts
+from .kamereon import has_required_contracts
 from .kamereon import models
 from .kamereon import schemas
 from .renault_session import RenaultSession
@@ -38,12 +40,13 @@ class RenaultVehicle:
         country: Optional[str] = None,
         locale_details: Optional[Dict[str, str]] = None,
         credential_store: Optional[CredentialStore] = None,
-        vehicle_details: Optional[models.KamereonVehiclesDetails] = None,
+        vehicle_details: Optional[models.KamereonVehicleDetails] = None,
     ) -> None:
         """Initialise Renault vehicle."""
         self._account_id = account_id
         self._vin = vin
         self._vehicle_details = vehicle_details
+        self._contracts: Optional[List[models.KamereonVehicleContract]] = None
 
         if session:
             self._session = session
@@ -75,8 +78,39 @@ class RenaultVehicle:
         """Get vin."""
         return self._vin
 
+    async def get_details(self) -> models.KamereonVehicleDetails:
+        """Get vehicle battery status."""
+        if self._vehicle_details:
+            return self._vehicle_details
+
+        response = await self.session.get_vehicle_details(
+            account_id=self.account_id,
+            vin=self.vin,
+        )
+        self._vehicle_details = cast(
+            models.KamereonVehicleDetails,
+            response,
+        )
+        return self._vehicle_details
+
+    async def get_contracts(self) -> List[models.KamereonVehicleContract]:
+        """Get vehicle contracts."""
+        # await self.warn_on_method("get_contracts")
+        if self._contracts:
+            return self._contracts
+
+        response = await self.session.get_vehicle_contracts(
+            account_id=self.account_id,
+            vin=self.vin,
+        )
+        if response.contractList is None:  # pragma: no cover
+            raise ValueError("response.contractList is None")
+        self._contracts = response.contractList
+        return self._contracts
+
     async def get_battery_status(self) -> models.KamereonVehicleBatteryStatusData:
         """Get vehicle battery status."""
+        # await self.warn_on_method("get_battery_status")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -89,6 +123,7 @@ class RenaultVehicle:
 
     async def get_location(self) -> models.KamereonVehicleLocationData:
         """Get vehicle location."""
+        # await self.warn_on_method("get_location")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -101,6 +136,7 @@ class RenaultVehicle:
 
     async def get_hvac_status(self) -> models.KamereonVehicleHvacStatusData:
         """Get vehicle hvac status."""
+        # await self.warn_on_method("get_hvac_status")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -113,6 +149,7 @@ class RenaultVehicle:
 
     async def get_hvac_settings(self) -> models.KamereonVehicleHvacSettingsData:
         """Get vehicle hvac settings (schedule+mode)."""
+        # await self.warn_on_method("get_hvac_settings")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -125,6 +162,7 @@ class RenaultVehicle:
 
     async def get_charge_mode(self) -> models.KamereonVehicleChargeModeData:
         """Get vehicle charge mode."""
+        # await self.warn_on_method("get_charge_mode")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -137,6 +175,7 @@ class RenaultVehicle:
 
     async def get_cockpit(self) -> models.KamereonVehicleCockpitData:
         """Get vehicle cockpit."""
+        # await self.warn_on_method("get_cockpit")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -149,6 +188,7 @@ class RenaultVehicle:
 
     async def get_lock_status(self) -> models.KamereonVehicleLockStatusData:
         """Get vehicle lock status."""
+        # await self.warn_on_method("get_lock_status")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -161,6 +201,7 @@ class RenaultVehicle:
 
     async def get_charging_settings(self) -> models.KamereonVehicleChargingSettingsData:
         """Get vehicle charging settings."""
+        # await self.warn_on_method("get_charging_settings")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -175,6 +216,7 @@ class RenaultVehicle:
         self,
     ) -> models.KamereonVehicleNotificationSettingsData:
         """Get vehicle notification settings."""
+        # await self.warn_on_method("get_notification_settings")
         response = await self.session.get_vehicle_data(
             account_id=self.account_id,
             vin=self.vin,
@@ -191,6 +233,7 @@ class RenaultVehicle:
         self, start: datetime, end: datetime, period: str
     ) -> models.KamereonVehicleChargeHistoryData:
         """Get vehicle charge history."""
+        # await self.warn_on_method("get_charge_history")
         if not isinstance(start, datetime):  # pragma: no cover
             raise TypeError(
                 "`start` should be an instance of datetime.datetime, not {}".format(
@@ -226,6 +269,7 @@ class RenaultVehicle:
         self, start: datetime, end: datetime
     ) -> models.KamereonVehicleChargesData:
         """Get vehicle charges."""
+        # await self.warn_on_method("get_charges")
         if not isinstance(start, datetime):  # pragma: no cover
             raise TypeError(
                 "`start` should be an instance of datetime.datetime, not {}".format(
@@ -258,6 +302,7 @@ class RenaultVehicle:
         self, start: datetime, end: datetime, period: str
     ) -> models.KamereonVehicleHvacHistoryData:
         """Get vehicle hvac history."""
+        # await self.warn_on_method("get_hvac_history")
         if not isinstance(start, datetime):  # pragma: no cover
             raise TypeError(
                 "`start` should be an instance of datetime.datetime, not {}".format(
@@ -293,6 +338,7 @@ class RenaultVehicle:
         self, start: datetime, end: datetime
     ) -> models.KamereonVehicleHvacSessionsData:
         """Get vehicle hvac sessions."""
+        # await self.warn_on_method("get_hvac_sessions")
         if not isinstance(start, datetime):  # pragma: no cover
             raise TypeError(
                 "`start` should be an instance of datetime.datetime, not {}".format(
@@ -325,6 +371,7 @@ class RenaultVehicle:
         self, temperature: float, when: Optional[datetime] = None
     ) -> models.KamereonVehicleHvacStartActionData:
         """Start vehicle ac."""
+        # await self.warn_on_method("set_ac_start")
         attributes = {
             "action": "start",
             "targetTemperature": temperature,
@@ -353,6 +400,7 @@ class RenaultVehicle:
 
     async def set_ac_stop(self) -> models.KamereonVehicleHvacStartActionData:
         """Stop vehicle ac."""
+        await self.warn_on_method("set_ac_stop")
         attributes = {"action": "cancel"}
 
         response = await self.session.set_vehicle_action(
@@ -370,6 +418,7 @@ class RenaultVehicle:
         self, schedules: List[models.HvacSchedule]
     ) -> models.KamereonVehicleHvacScheduleActionData:
         """Set vehicle charge schedules."""
+        # await self.warn_on_method("set_hvac_schedules")
         for schedule in schedules:
             if not isinstance(schedule, models.HvacSchedule):  # pragma: no cover
                 raise TypeError(
@@ -396,6 +445,7 @@ class RenaultVehicle:
         self, schedules: List[models.ChargeSchedule]
     ) -> models.KamereonVehicleChargeScheduleActionData:
         """Set vehicle charge schedules."""
+        # await self.warn_on_method("set_charge_schedules")
         for schedule in schedules:
             if not isinstance(schedule, models.ChargeSchedule):  # pragma: no cover
                 raise TypeError(
@@ -422,6 +472,7 @@ class RenaultVehicle:
         self, charge_mode: str
     ) -> models.KamereonVehicleChargeModeActionData:
         """Set vehicle charge mode."""
+        # await self.warn_on_method("set_charge_mode")
         attributes = {"action": charge_mode}
 
         response = await self.session.set_vehicle_action(
@@ -437,6 +488,7 @@ class RenaultVehicle:
 
     async def set_charge_start(self) -> models.KamereonVehicleChargingStartActionData:
         """Start vehicle charge."""
+        # await self.warn_on_method("set_charge_start")
         attributes = {"action": "start"}
 
         response = await self.session.set_vehicle_action(
@@ -451,3 +503,24 @@ class RenaultVehicle:
                 schemas.KamereonVehicleChargingStartActionDataSchema
             ),
         )
+
+    async def supports_endpoint(self, endpoint: str) -> bool:
+        """Check if vehicle supports endpoint."""
+        details = await self.get_details()
+        return details.supports_endpoint(endpoint)
+
+    async def has_contract_for_endpoint(self, endpoint: str) -> bool:
+        """Check if vehicle has contract for endpoint."""
+        required_contracts = get_required_contracts(endpoint)
+        if not required_contracts:
+            return True
+
+        contracts = await self.get_contracts()
+        return has_required_contracts(contracts, endpoint)
+
+    async def warn_on_method(self, method: str) -> None:
+        """Log a warning if the method requires it."""
+        details = await self.get_details()
+        warning = details.warns_on_method(method)
+        if warning:
+            _LOGGER.warning(warning)
